# Instructions

#### This is our first project.


#### Please install this package
```

pip install functions_by_nasiba_87
```

#### You can also install older packages

```
pip install functions_by_nasiba_87==VERSION_NUMBER